==> umbraco-0.0.4.tgz: package/src/generic/initializeGitRepo.ts <==
import { execSync } from "child_process";
import * as fs from "fs";
import * as path from "path";
import { fileURLToPath } from "url";

export const initializeGitRepo = async (
  dir: string,
  { projectName, useUmbraco, gitRepo }: any
): Promise<void> => {
  if (gitRepo !== "") {
    console.log(`Initializing Git repository in ${dir}\n`);

    createGitignoreUmbraco(dir, projectName, useUmbraco);

    try {
      execSync(`git init`, { cwd: dir });
      console.log(`Git repository initialized successfully`);

      execSync(`git add .`, { cwd: dir });
      console.log(`Files added to Git successfully`);

      try {
        execSync(`git commit -m "Initial commit"`, { cwd: dir });
        console.log(`Files committed to Git successfully`);
      } catch (commitError) {
        console.error(`Error committing files: ${commitError}`);
        return; // Exit the function if commit fails
      }

      // Check if the remote repository "origin" already exists
      try {
        console.log(`Checking if remote "origin" exists...`);
        execSync(`git remote get-url origin`, { cwd: dir });
        console.log(`Remote "origin" already exists. Updating the URL...`);
        execSync(`git remote set-url origin ${gitRepo}`, { cwd: dir });
        console.log(`Remote repository URL updated successfully`);
      } catch (error) {
        console.log(`Remote "origin" does not exist. Adding remote repository...`);
        execSync(`git remote add origin ${gitRepo}`, { cwd: dir });
        console.log(`Remote repository added successfully`);
      }

      // Check if the current branch is "master" and rename it to "main"
      try {
        const currentBranch = execSync(`git branch --show-current`, { cwd: dir }).toString().trim();
        if (currentBranch === "master") {
          execSync(`git branch -m master main`, { cwd: dir });
          console.log(`Branch renamed to main successfully`);
        } else {
          console.log(`No need to rename branch, it is already "${currentBranch}".`);
        }
      } catch (error) {
        console.log(`Error checking or renaming branch: ${error}`);
      }

      try {
        execSync(`git push -u origin main --force`, { cwd: dir });
        console.log(`Pushed to remote repository successfully`);
      } catch (pushError) {
        console.error(`Error pushing to remote repository: ${pushError}`);
        console.log(
          `Please ensure the remote repository exists and you have the correct permissions.`
        );
      }
    } catch (error) {
      console.error(`Error initializing Git repository: ${error}`);
    }
  }
};

const createGitignoreUmbraco = (dir: string, projectName: string, useUmbraco: boolean): void => {
  const __filename = fileURLToPath(import.meta.url);
  const __dirname = path.dirname(__filename);
  const frontendGitignorePath = path.join(__dirname, "..", "files", "frontend.gitignore");
  let gitignoreContent = "";

  if (fs.existsSync(frontendGitignorePath)) {
    gitignoreContent += fs.readFileSync(frontendGitignorePath, "utf-8") + "\n";
  }

  if (useUmbraco) {
    const umbracoGitignorePath = path.join(__dirname, "..", "files", "umbraco.gitignore");
    if (fs.existsSync(umbracoGitignorePath)) {
      gitignoreContent += fs.readFileSync(umbracoGitignorePath, "utf-8") + "\n";
    }
  }

  const gitignorePath = path.join(dir, ".gitignore");
  fs.writeFileSync(gitignorePath, gitignoreContent, "utf-8");

  if (useUmbraco) {
    replaceInFile(gitignorePath, "{{NAME}}", projectName);
  } else {
    replaceInFile(gitignorePath, "{{NAME}}/", "");
  }

  console.log(`.gitignore created successfully at ${gitignorePath}`);
};

const replaceInFile = (filePath: string, searchValue: string, replaceValue: string): void => {
  const fileContent = fs.readFileSync(filePath, "utf-8");
  const updatedContent = fileContent.replace(new RegExp(searchValue, "g"), replaceValue);
  fs.writeFileSync(filePath, updatedContent, "utf-8");
};

==> umbraco-0.0.6.tgz: package/src/generic/initializeGitRepo.ts <==
import { execSync } from "child_process";
import * as fs from "fs";
import * as path from "path";
import { fileURLToPath } from "url";

export const initializeGitRepo = async (
  dir: string,
  { projectName, useUmbraco, gitRepo }: any
): Promise<void> => {
  if (gitRepo !== "") {
    createGitignoreUmbraco(dir, projectName, useUmbraco);

    try {
      process.stdout.write(`Initializing Git repository...`);
      execSync(`git init`, { cwd: dir });
      process.stdout.write(` Done \n`);

      process.stdout.write(`Adding files to Git...`);
      execSync(`git add .`, { cwd: dir });
      process.stdout.write(` Done \n`);

      try {
        process.stdout.write(`Committing files to Git...`);
        execSync(`git commit -m "Initial commit"`, { cwd: dir });
        process.stdout.write(` Done \n`);
      } catch (commitError) {
        console.error(`Error committing files: ${commitError}`);
        return; // Exit the function if commit fails
      }

      // Check if the remote repository "origin" already exists
      try {
        process.stdout.write(`Checking if remote repository "origin" already exists...`);
        execSync(`git remote get-url origin`, { cwd: dir });
        process.stdout.write(` Done \n Remote "origin" already exists. Updating the URL...`);
        execSync(`git remote set-url origin ${gitRepo}`, { cwd: dir });
        process.stdout.write(`Done \n`);
      } catch (error) {
        process.stdout.write(`Remote "origin" does not exist. Adding remote repository...`);
        execSync(`git remote add origin ${gitRepo}`, { cwd: dir });
        process.stdout.write(`Done \n`);
      }

      // Check if the current branch is "master" and rename it to "main"
      try {
        const currentBranch = execSync(`git branch --show-current`, { cwd: dir }).toString().trim();
        if (currentBranch === "master") {
          process.stdout.write(`Renaming branch from master to main...`);
          execSync(`git branch -m master main`, { cwd: dir });
          process.stdout.write(`Done \n`);
        } else {
          console.log(`No need to rename branch, it is already "${currentBranch}".`);
        }
      } catch (error) {
        console.log(`Error checking or renaming branch: ${error}`);
      }

      try {
        process.stdout.write(`Pushing to remote repository...`);
        execSync(`git push -u origin main --force`, { cwd: dir });
        process.stdout.write(` Done \n`);
      } catch (pushError) {
        console.error(`Error pushing to remote repository: ${pushError}`);
        console.log(
          `Please ensure the remote repository exists and you have the correct permissions.`
        );
      }
    } catch (error) {
      console.error(`Error initializing Git repository: ${error}`);
    }
  }
};

const createGitignoreUmbraco = (dir: string, projectName: string, useUmbraco: boolean): void => {
  const __filename = fileURLToPath(import.meta.url);
  const __dirname = path.dirname(__filename);
  const frontendGitignorePath = path.join(__dirname, "..", "files", "frontend.gitignore");
  let gitignoreContent = "";

  process.stdout.write(`Creating .gitignore file...`);
  if (fs.existsSync(frontendGitignorePath)) {
    gitignoreContent += fs.readFileSync(frontendGitignorePath, "utf-8") + "\n";
  }

  if (useUmbraco) {
    const umbracoGitignorePath = path.join(__dirname, "..", "files", "umbraco.gitignore");
    if (fs.existsSync(umbracoGitignorePath)) {
      gitignoreContent += fs.readFileSync(umbracoGitignorePath, "utf-8") + "\n";
    }
  }

  const gitignorePath = path.join(dir, ".gitignore");
  fs.writeFileSync(gitignorePath, gitignoreContent, "utf-8");

  if (useUmbraco) {
    replaceInFile(gitignorePath, "{{NAME}}", projectName);
  } else {
    replaceInFile(gitignorePath, "{{NAME}}/", "");
  }

  process.stdout.write(`Done \n`);
};

const replaceInFile = (filePath: string, searchValue: string, replaceValue: string): void => {
  const fileContent = fs.readFileSync(filePath, "utf-8");
  const updatedContent = fileContent.replace(new RegExp(searchValue, "g"), replaceValue);
  fs.writeFileSync(filePath, updatedContent, "utf-8");
};
